@@ -3,12 +3,12 @@ mpcls <- function(y, x) {
   dm <- dim(x)
   n <- dm[1]   ;   p <- dm[2]
   d <- dim(y)[2]
-  dvec <-  2 * crossprod(x, y)
+  dvec <-  crossprod(x, y)
 
-  xx <- 2 * crossprod(x)
+  xx <- crossprod(x)
   A <- cbind(1, diag(p) )
   bvec <- c(1, rep(0, p) )
-  mse <- rep( sum(y^2), d)
+  mse <- numeric(d)
   be <- matrix(nrow = p, ncol = d)
 
   for ( j in 1:d ) {
@@ -16,7 +16,7 @@ mpcls <- function(y, x) {
     be[, j] <- f$solution
     mse[j] <- f$value
   }
-  mse <- ( mse + Rfast::colsums(y^2) ) / n
+  mse <- ( 2 * mse + Rfast::colsums(y^2) ) / n
   rownames(be) <- colnames(x)
   list(be = be, mse = mse)
 }
